DeviceLocationService class
Constructors
- DeviceLocationService({required LocationPermissionHandler locationPermissionHandler})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → Location
-
final
- locationPermissionHandler → LocationPermissionHandler
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readDeviceDetails(
List args) → Future< DeviceLocationModel> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited